/**
 * @module direction/utils
 */

/**
 * The list of supported direction options:
 *
 * * `'ltr'`,
 * * `'rtl'`,
 */
export const supportedOptions = [ 'ltr', 'rtl' ];

/**
 * Checks whether the passed option is supported by {@link module:direction/directionediting~DirectionEditing}.
 *
 * @param {String} option The option value to check.
 * @returns {Boolean}
 */
export function isSupported( option ) {
  return supportedOptions.includes( option );
}

/**
 * Checks whether direction is the default one (based on editor's locale config).
 *
 * @param {String} direction The name of the direction to check.
 * @param {String} locale The editor locale config.
 *
 * @returns {Boolean}
 */
export function isDefault( direction, locale ) {
  // Checks editor locale contentLanguageDirection config and set default value.
  // Docs: https://ckeditor.com/docs/ckeditor5/latest/api/module_core_editor_editorconfig-EditorConfig.html#member-language
  if ( locale.contentLanguageDirection == 'rtl' ) {
      return direction === 'rtl';
    } else {
      return direction === 'ltr';
    }
}
